Module BuildInfo

Module BuildInfo 

Constants

INVALID
Invalid data type. Never results in any data extraction.
KITTY_GRAPHICS
Whether Kitty graphics protocol support is available.
MAX_VALUE
The build metadata string (e.g. commit hash). Has zero length if no build metadata is present.
OPTIMIZE
The optimization mode the library was built with.
SIMD
Whether SIMD-accelerated code paths are enabled.
TMUX_CONTROL_MODE
Whether tmux control mode support is available.
VERSION_BUILD
The build metadata string (e.g. commit hash). Has zero length if no build metadata is present.
VERSION_MAJOR
The major version number.
VERSION_MINOR
The minor version number.
VERSION_PATCH
The patch version number.
VERSION_PRE
The pre metadata string (e.g. “alpha”, “beta”, “dev”). Has zero length if no pre metadata is present.
VERSION_STRING
The full version string (e.g. “1.2.3” or “1.2.3-dev+abcdef”).

Type Aliases

Type
Build info data types that can be queried.