Module KittyGraphicsData

Module KittyGraphicsData 

Constants

INVALID
Invalid / sentinel value.
MAX_VALUE
Populate a pre-allocated placement iterator with placement data from the storage. Iterator data is only valid as long as the underlying terminal is not mutated.
PLACEMENT_ITERATOR
Populate a pre-allocated placement iterator with placement data from the storage. Iterator data is only valid as long as the underlying terminal is not mutated.

Type Aliases

Type
Queryable data kinds for ghostty_kitty_graphics_get().