Module KittyGraphicsPlacementData

Module KittyGraphicsPlacementData 

Constants

COLUMNS
Number of columns this placement occupies.
IMAGE_ID
The image ID this placement belongs to.
INVALID
Invalid / sentinel value.
IS_VIRTUAL
Whether this is a virtual placement (unicode placeholder).
MAX_VALUE
Z-index for this placement.
PLACEMENT_ID
The placement ID.
ROWS
Number of rows this placement occupies.
SOURCE_HEIGHT
Source rectangle height in pixels (0 = full image height).
SOURCE_WIDTH
Source rectangle width in pixels (0 = full image width).
SOURCE_X
Source rectangle x origin in pixels.
SOURCE_Y
Source rectangle y origin in pixels.
X_OFFSET
Pixel offset from the left edge of the cell.
Y_OFFSET
Pixel offset from the top edge of the cell.
Z
Z-index for this placement.

Type Aliases

Type
Queryable data kinds for ghostty_kitty_graphics_placement_get().