Module MouseEncoderOption

Module MouseEncoderOption 

Constants

ANY_BUTTON_PRESSED
Whether any mouse button is currently pressed (value: bool).
EVENT
Mouse tracking mode (value: GhosttyMouseTrackingMode).
FORMAT
Mouse output format (value: GhosttyMouseFormat).
MAX_VALUE
Whether to enable motion deduplication by last cell (value: bool).
SIZE
Renderer size context (value: GhosttyMouseEncoderSize).
TRACK_LAST_CELL
Whether to enable motion deduplication by last cell (value: bool).

Type Aliases

Type
Mouse encoder option identifiers.