Module RenderStateRowData

Module RenderStateRowData 

Constants

CELLS
Populate a pre-allocated GhosttyRenderStateRowCells with cell data for the current row (GhosttyRenderStateRowCells). Cell data is only valid as long as the underlying render state is not updated. It is unsafe to use cell data after updating the render state.
DIRTY
Whether the current row is dirty (bool).
INVALID
Invalid / sentinel value.
MAX_VALUE
Row-local selected cell range (GhosttyRenderStateRowSelection).
RAW
The raw row value (GhosttyRow).
SELECTION
Row-local selected cell range (GhosttyRenderStateRowSelection).

Type Aliases

Type
Queryable data kinds for ghostty_render_state_row_get().