Module RowData

Module RowData 

Constants

DIRTY
Whether this row is dirty and requires a redraw.
GRAPHEME
Whether any cells in this row have grapheme clusters.
HYPERLINK
Whether any cells in this row have hyperlinks (may have false positives).
INVALID
Invalid data type. Never results in any data extraction.
KITTY_VIRTUAL_PLACEHOLDER
Whether this row contains a Kitty virtual placeholder.
MAX_VALUE
Whether this row is dirty and requires a redraw.
SEMANTIC_PROMPT
The semantic prompt state of this row.
STYLED
Whether any cells in this row have styling (may have false positives).
WRAP
Whether this row is soft-wrapped.
WRAP_CONTINUATION
Whether this row is a continuation of a soft-wrapped row.

Type Aliases

Type
Row data types.