Module RowSemanticPrompt

Module RowSemanticPrompt 

Constants

MAX_VALUE
Prompt cells exist and this is a continuation line.
NONE
No prompt cells in this row.
PROMPT
Prompt cells exist and this is a primary prompt line.
PROMPT_CONTINUATION
Prompt cells exist and this is a continuation line.

Type Aliases

Type
Row semantic prompt state.