Type

Type Alias Type 

pub type Type = c_uint;
Selection gesture event type.

The event type is fixed when the event is created. Each event type documents which options are valid and which options are required by gesture operations.