Module TerminalData

Module TerminalData 

Constants

ACTIVE_SCREEN
The currently active screen.
COLOR_BACKGROUND
The effective background color (override or default).
COLOR_BACKGROUND_DEFAULT
The default background color (ignoring any OSC override).
COLOR_CURSOR
The effective cursor color (override or default).
COLOR_CURSOR_DEFAULT
The default cursor color (ignoring any OSC override).
COLOR_FOREGROUND
The effective foreground color (override or default).
COLOR_FOREGROUND_DEFAULT
The default foreground color (ignoring any OSC override).
COLOR_PALETTE
The current 256-color palette.
COLOR_PALETTE_DEFAULT
The default 256-color palette (ignoring any OSC overrides).
COLS
Terminal width in cells.
CURSOR_PENDING_WRAP
Whether the cursor has a pending wrap (next print will soft-wrap).
CURSOR_STYLE
The current SGR style of the cursor.
CURSOR_VISIBLE
Whether the cursor is visible (DEC mode 25).
CURSOR_X
Cursor column position (0-indexed).
CURSOR_Y
Cursor row position within the active area (0-indexed).
HEIGHT_PX
The total height of the terminal in pixels.
INVALID
Invalid data type. Never results in any data extraction.
KITTY_GRAPHICS
The Kitty graphics image storage for the active screen.
KITTY_IMAGE_MEDIUM_FILE
Whether the file medium is enabled for Kitty image loading on the active screen.
KITTY_IMAGE_MEDIUM_SHARED_MEM
Whether the shared memory medium is enabled for Kitty image loading on the active screen.
KITTY_IMAGE_MEDIUM_TEMP_FILE
Whether the temporary file medium is enabled for Kitty image loading on the active screen.
KITTY_IMAGE_STORAGE_LIMIT
The Kitty image storage limit in bytes for the active screen.
KITTY_KEYBOARD_FLAGS
Current Kitty keyboard protocol flags.
MAX_VALUE
Whether the viewport is currently pinned to the active area.
MOUSE_TRACKING
Whether any mouse tracking mode is active.
PWD
The terminal’s current working directory as set by escape sequences (e.g. OSC 7).
ROWS
Terminal height in cells.
SCROLLBACK_ROWS
The number of scrollback rows (total rows minus viewport rows).
SCROLLBAR
Scrollbar state for the terminal viewport.
SELECTION
The active screen’s current selection.
TITLE
The terminal title as set by escape sequences (e.g. OSC 0/2).
TOTAL_ROWS
The total number of rows in the active screen including scrollback.
VIEWPORT_ACTIVE
Whether the viewport is currently pinned to the active area.
WIDTH_PX
The total width of the terminal in pixels.

Type Aliases

Type
Terminal data types.