Set the maximum bytes the APC handler will buffer for all protocols.
This prevents malicious input from causing unbounded memory allocation.
A NULL value pointer removes all overrides, reverting to the built-in
defaults.
Set the maximum bytes the APC handler will buffer for Kitty graphics
protocol data. A NULL value pointer removes the override, reverting
to the built-in default.
Callback invoked when the running program performs a clipboard write.
OSC 52 and iTerm2 OSC 1337 Copy writes are normalized to an atomic set
of decoded MIME representations. Set to NULL to ignore clipboard writes.
Clipboard read requests are always ignored; see
GhosttyTerminalClipboardWriteFn.
Callback invoked in response to a color scheme device status
report query (CSI ? 996 n). Return true and fill the out pointer
to report the current scheme, or return false to silently ignore.
Set to NULL to ignore color scheme queries.
Callback invoked in response to a device attributes query
(CSI c, CSI > c, or CSI = c). Return true and fill the out
pointer with response data, or return false to silently ignore.
Set to NULL to ignore device attributes queries.
Callback invoked when the running program performs a clipboard write.
OSC 52 and iTerm2 OSC 1337 Copy writes are normalized to an atomic set
of decoded MIME representations. Set to NULL to ignore clipboard writes.
Clipboard read requests are always ignored; see
GhosttyTerminalClipboardWriteFn.
Callback invoked when the terminal needs to write data back
to the pty (e.g. in response to a DECRQM query or device
status report). Set to NULL to ignore such sequences.