ghostty_cell_get

Function ghostty_cell_get 

pub unsafe extern "C" fn ghostty_cell_get(
    cell: GhosttyCell,
    data: GhosttyCellData,
    out: *mut c_void,
) -> GhosttyResult
Get data from a cell.

Extracts typed data from the given cell based on the specified data type. The output pointer must be of the appropriate type for the requested data kind. Valid data types and output types are documented in the GhosttyCellData enum.

@param cell The cell value @param data The type of data to extract @param out Pointer to store the extracted data (type depends on data parameter) @return GHOSTTY_SUCCESS on success, GHOSTTY_INVALID_VALUE if the data type is invalid

@ingroup screen