ghostty_key_event_set_composing

Function ghostty_key_event_set_composing 

pub unsafe extern "C" fn ghostty_key_event_set_composing(
    event: GhosttyKeyEvent_ptr,
    composing: bool,
)
Set whether the key event is part of a composition sequence.

@param event The key event handle, must not be NULL @param composing Whether the key event is part of a composition sequence

@ingroup key