ghostty_mouse_encoder_new

Function ghostty_mouse_encoder_new 

pub unsafe extern "C" fn ghostty_mouse_encoder_new(
    allocator: *const GhosttyAllocator,
    encoder: *mut GhosttyMouseEncoder_ptr,
) -> GhosttyResult
Create a new mouse encoder instance.

@param allocator Pointer to allocator, or NULL to use the default allocator @param encoder Pointer to store the created encoder handle @return GHOSTTY_SUCCESS on success, or an error code on failure

@ingroup mouse