ghostty_mouse_event_set_button

Function ghostty_mouse_event_set_button 

pub unsafe extern "C" fn ghostty_mouse_event_set_button(
    event: GhosttyMouseEvent_ptr,
    button: GhosttyMouseButton,
)
Set the event button.

This sets a concrete button identity for the event. To represent “no button” (for motion events), use ghostty_mouse_event_clear_button().

@param event The event handle, must not be NULL @param button The button to set

@ingroup mouse