ghostty_render_state_row_get

Function ghostty_render_state_row_get 

pub unsafe extern "C" fn ghostty_render_state_row_get(
    iterator: GhosttyRenderStateRowIterator_ptr,
    data: GhosttyRenderStateRowData,
    out: *mut c_void,
) -> GhosttyResult
Get a value from the current row in a render-state row iterator.

The out pointer must point to a value of the type corresponding to the requested data kind (see GhosttyRenderStateRowData). Call ghostty_render_state_row_iterator_next() at least once before calling this function.

@param iterator The iterator handle to query (NULL returns GHOSTTY_INVALID_VALUE) @param data The data kind to query @param[out] out Pointer to receive the queried value @return GHOSTTY_SUCCESS on success, GHOSTTY_INVALID_VALUE if iterator is NULL or the iterator is not positioned on a row

@ingroup render