ghostty_render_state_row_iterator_new

Function ghostty_render_state_row_iterator_new 

pub unsafe extern "C" fn ghostty_render_state_row_iterator_new(
    allocator: *const GhosttyAllocator,
    out_iterator: *mut GhosttyRenderStateRowIterator_ptr,
) -> GhosttyResult
Create a new row iterator instance.

All fields except the allocator are left undefined until populated via ghostty_render_state_get() with GHOSTTY_RENDER_STATE_DATA_ROW_ITERATOR.

@param allocator Pointer to allocator, or NULL to use the default allocator @param[out] out_iterator On success, receives the created iterator handle @return GHOSTTY_SUCCESS on success, GHOSTTY_OUT_OF_MEMORY on allocation failure

@ingroup render