ghostty_render_state_row_iterator_next

Function ghostty_render_state_row_iterator_next 

pub unsafe extern "C" fn ghostty_render_state_row_iterator_next(
    iterator: RenderStateRowIterator,
) -> bool
Move a render-state row iterator to the next row.

Returns true if the iterator moved successfully and row data is available to read at the new position.

    NULL or if the iterator has reached the end