ghostty_render_state_row_set

Function ghostty_render_state_row_set 

pub unsafe extern "C" fn ghostty_render_state_row_set(
    iterator: GhosttyRenderStateRowIterator_ptr,
    option: GhosttyRenderStateRowOption,
    value: *const c_void,
) -> GhosttyResult
Set an option on the current row in a render-state row iterator.

The value pointer must point to a value of the type corresponding to the requested option kind (see GhosttyRenderStateRowOption). Call ghostty_render_state_row_iterator_next() at least once before calling this function.

@param iterator The iterator handle to update (NULL returns GHOSTTY_INVALID_VALUE) @param option The option to set @param[in] value Pointer to the value to set (NULL returns GHOSTTY_INVALID_VALUE) @return GHOSTTY_SUCCESS on success, GHOSTTY_INVALID_VALUE if iterator is NULL or the iterator is not positioned on a row

@ingroup render