ghostty_render_state_set

Function ghostty_render_state_set 

pub unsafe extern "C" fn ghostty_render_state_set(
    state: GhosttyRenderState_ptr,
    option: GhosttyRenderStateOption,
    value: *const c_void,
) -> GhosttyResult
Set an option on a render state.

The value pointer must point to a value of the type corresponding to the requested option kind (see GhosttyRenderStateOption).

@param state The render state handle (NULL returns GHOSTTY_INVALID_VALUE) @param option The option to set @param[in] value Pointer to the value to set (NULL returns GHOSTTY_INVALID_VALUE) @return GHOSTTY_SUCCESS on success, GHOSTTY_INVALID_VALUE if state or value is NULL

@ingroup render