ghostty_sgr_unknown_partial

Function ghostty_sgr_unknown_partial 

pub unsafe extern "C" fn ghostty_sgr_unknown_partial(
    unknown: GhosttySgrUnknown,
    ptr: *mut *const u16,
) -> usize
Get the partial parameter list from an unknown SGR attribute.

This function retrieves the partial parameter list where parsing stopped when an unknown attribute was encountered. Primarily useful in WebAssembly environments where accessing struct fields directly is difficult.

@param unknown The unknown attribute data @param ptr Pointer to store the pointer to the parameter array (may be NULL) @return The length of the partial parameter array

@ingroup sgr