#[repr(C)]pub struct FormatterTerminalExtra {
pub size: usize,
pub palette: bool,
pub modes: bool,
pub scrolling_region: bool,
pub tabstops: bool,
pub pwd: bool,
pub keyboard: bool,
pub screen: FormatterScreenExtra,
}Expand description
Extra terminal state to include in styled output.
Fields
size: usizeSize of this struct in bytes. Must be set to sizeof(GhosttyFormatterTerminalExtra).
palette: boolEmit the palette using OSC 4 sequences.
modes: boolEmit terminal modes that differ from their defaults using CSI h/l.
scrolling_region: boolEmit scrolling region state using DECSTBM and DECSLRM sequences.
tabstops: boolEmit tabstop positions by clearing all tabs and setting each one.
pwd: boolEmit the present working directory using OSC 7.
keyboard: boolEmit keyboard modes such as ModifyOtherKeys.
screen: FormatterScreenExtraScreen-level extras.