GhosttyFormatterTerminalExtra

Struct GhosttyFormatterTerminalExtra 

#[repr(C)]
pub struct GhosttyFormatterTerminalExtra { pub size: usize, pub palette: bool, pub modes: bool, pub scrolling_region: bool, pub tabstops: bool, pub pwd: bool, pub keyboard: bool, pub screen: GhosttyFormatterScreenExtra, }
Extra terminal state to include in styled output.

@ingroup formatter

Fields

size: usize

Size of this struct in bytes. Must be set to sizeof(GhosttyFormatterTerminalExtra).

palette: bool

Emit the palette using OSC 4 sequences.

modes: bool

Emit terminal modes that differ from their defaults using CSI h/l.

scrolling_region: bool

Emit scrolling region state using DECSTBM and DECSLRM sequences.

tabstops: bool

Emit tabstop positions by clearing all tabs and setting each one.

pwd: bool

Emit the present working directory using OSC 7.

keyboard: bool

Emit keyboard modes such as ModifyOtherKeys.

screen: GhosttyFormatterScreenExtra

Screen-level extras.