#[repr(C)]pub struct GhosttyRenderStateColors {
pub size: usize,
pub background: GhosttyColorRgb,
pub foreground: GhosttyColorRgb,
pub cursor: GhosttyColorRgb,
pub cursor_has_value: bool,
pub palette: [GhosttyColorRgb; 256],
}Expand description
Render-state color information.
This struct uses the sized-struct ABI pattern. Initialize with GHOSTTY_INIT_SIZED(GhosttyRenderStateColors) before calling ghostty_render_state_colors_get().
Example: @code GhosttyRenderStateColors colors = GHOSTTY_INIT_SIZED(GhosttyRenderStateColors); GhosttyResult result = ghostty_render_state_colors_get(state, &colors); @endcode
@ingroup render
Fields
size: usizeSize of this struct in bytes. Must be set to sizeof(GhosttyRenderStateColors).
background: GhosttyColorRgbThe default/current background color for the render state.
foreground: GhosttyColorRgbThe default/current foreground color for the render state.
cursor: GhosttyColorRgbThe cursor color when explicitly set by terminal state.
cursor_has_value: boolTrue when cursor contains a valid explicit cursor color value. If this is false, the cursor color should be ignored; it will contain undefined data.
palette: [GhosttyColorRgb; 256]The active 256-color palette for this render state.