#[repr(C)]pub struct GhosttySgrAttribute {
pub tag: GhosttySgrAttributeTag,
pub value: GhosttySgrAttributeValue,
}Expand description
SGR attribute (tagged union).
A complete SGR attribute with both its type tag and associated value. Always check the tag field to determine which value union member is valid.
Attributes without associated data (e.g., GHOSTTY_SGR_ATTR_BOLD) can be identified by tag alone; the value union is not used for these and the memory in the value field is undefined.
@ingroup sgr
Fields
tag: GhosttySgrAttributeTagvalue: GhosttySgrAttributeValueTrait Implementations
Sourceimpl Clone for GhosttySgrAttribute
impl Clone for GhosttySgrAttribute
Sourcefn clone(&self) -> GhosttySgrAttribute
fn clone(&self) -> GhosttySgrAttribute
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for GhosttySgrAttribute
impl Default for GhosttySgrAttribute
impl Copy for GhosttySgrAttribute