#[repr(C)]pub struct GhosttySgrUnknown {
pub full_ptr: *const u16,
pub full_len: usize,
pub partial_ptr: *const u16,
pub partial_len: usize,
}Expand description
Unknown SGR attribute data.
Contains the full parameter list and the partial list where parsing encountered an unknown or invalid sequence.
@ingroup sgr
Fields
full_ptr: *const u16full_len: usizepartial_ptr: *const u16partial_len: usizeTrait Implementations
Sourceimpl Clone for GhosttySgrUnknown
impl Clone for GhosttySgrUnknown
Sourcefn clone(&self) -> GhosttySgrUnknown
fn clone(&self) -> GhosttySgrUnknown
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GhosttySgrUnknown
impl Debug for GhosttySgrUnknown
Sourceimpl Default for GhosttySgrUnknown
impl Default for GhosttySgrUnknown
impl Copy for GhosttySgrUnknown