#[repr(C)]pub struct GhosttyTerminalScrollbar {
pub total: u64,
pub offset: u64,
pub len: u64,
}Expand description
Scrollbar state for the terminal viewport.
Represents the scrollable area dimensions needed to render a scrollbar.
@ingroup terminal
Fields
total: u64Total size of the scrollable area in rows.
offset: u64Offset into the total area that the viewport is at.
len: u64Length of the visible area in rows.