#[repr(C)]pub struct SelectionGestureGeometry {
pub columns: u32,
pub cell_width: u32,
pub padding_left: u32,
pub screen_height: u32,
}Expand description
Display geometry used to interpret selection gesture drag events.
Fields
columns: u32Number of columns in the rendered terminal grid. Must be non-zero.
cell_width: u32Width of one terminal cell in surface pixels. Must be non-zero.
padding_left: u32Left padding before the terminal grid begins in surface pixels.
screen_height: u32Height of the rendered terminal surface in surface pixels. Must be non-zero.