#[repr(C)]pub struct SgrAttribute {
pub tag: Type,
pub value: SgrAttributeValue,
}Expand description
SGR attribute (tagged union).
A complete SGR attribute with both its type tag and associated value. Always check the tag field to determine which value union member is valid.
Attributes without associated data (e.g., GHOSTTY_SGR_ATTR_BOLD) can be identified by tag alone; the value union is not used for these and the memory in the value field is undefined.
Fields
tag: Typevalue: SgrAttributeValueTrait Implementations
Sourceimpl Clone for SgrAttribute
impl Clone for SgrAttribute
Sourcefn clone(&self) -> SgrAttribute
fn clone(&self) -> SgrAttribute
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SgrAttribute