#[repr(C)]pub struct SgrUnknown {
pub full_ptr: *const u16,
pub full_len: usize,
pub partial_ptr: *const u16,
pub partial_len: usize,
}Expand description
Unknown SGR attribute data.
Contains the full parameter list and the partial list where parsing encountered an unknown or invalid sequence.
Fields
full_ptr: *const u16full_len: usizepartial_ptr: *const u16partial_len: usizeTrait Implementations
Sourceimpl Clone for SgrUnknown
impl Clone for SgrUnknown
Sourcefn clone(&self) -> SgrUnknown
fn clone(&self) -> SgrUnknown
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SgrUnknown
Sourceimpl Debug for SgrUnknown
impl Debug for SgrUnknown