#[repr(C)]pub struct Style {Show 13 fields
pub size: usize,
pub fg_color: StyleColor,
pub bg_color: StyleColor,
pub underline_color: StyleColor,
pub bold: bool,
pub italic: bool,
pub faint: bool,
pub blink: bool,
pub inverse: bool,
pub invisible: bool,
pub strikethrough: bool,
pub overline: bool,
pub underline: c_int,
}Expand description
Terminal cell style.
Describes the complete visual style for a terminal cell, including foreground, background, and underline colors, as well as text decoration flags. The underline field uses the same values as GhosttySgrUnderline.
This is a sized struct. Use GHOSTTY_INIT_SIZED() to initialize it.
Fields
size: usizefg_color: StyleColorbg_color: StyleColorunderline_color: StyleColorbold: boolitalic: boolfaint: boolblink: boolinverse: boolinvisible: boolstrikethrough: booloverline: boolunderline: c_int< One of GHOSTTY_SGR_UNDERLINE_* values