SysImage

Struct SysImage 

#[repr(C)]
pub struct SysImage { pub width: u32, pub height: u32, pub data: *mut u8, pub data_len: usize, }
Result of decoding an image.

The data buffer must be allocated through the allocator provided to the decode callback. The library takes ownership and will free it with the same allocator.

Fields

width: u32

Image width in pixels.

height: u32

Image height in pixels.

data: *mut u8

Pointer to the decoded RGBA pixel data.

data_len: usize

Length of the pixel data in bytes.