TerminalSelectLineOptions

Struct TerminalSelectLineOptions 

#[repr(C)]
pub struct TerminalSelectLineOptions { pub size: usize, pub ref_: GridRef, pub whitespace: *const u32, pub whitespace_len: usize, pub semantic_prompt_boundary: bool, }
Options for deriving a line selection from a terminal grid reference.

This is a sized struct. Use GHOSTTY_INIT_SIZED() to initialize it. If whitespace is NULL and whitespace_len is 0, Ghostty’s default line-trim whitespace codepoints are used. If whitespace_len is non-zero, whitespace must not be NULL.

Fields

size: usize

Size of this struct in bytes. Must be set to sizeof(GhosttyTerminalSelectLineOptions).

ref_: GridRef

Grid reference under which to derive the line selection.

whitespace: *const u32

Optional codepoints to trim from the start and end of the line.

whitespace_len: usize

Number of entries in whitespace.

semantic_prompt_boundary: bool

Whether semantic prompt state changes should bound the line selection.