#[repr(C)]pub struct TerminalSelectWordOptions {
pub size: usize,
pub ref_: GridRef,
pub boundary_codepoints: *const u32,
pub boundary_codepoints_len: usize,
}Expand description
Options for deriving a word selection from a terminal grid reference.
This is a sized struct. Use GHOSTTY_INIT_SIZED() to initialize it. If boundary_codepoints is NULL and boundary_codepoints_len is 0, Ghostty’s default word-boundary codepoints are used. If boundary_codepoints_len is non-zero, boundary_codepoints must not be NULL.
Fields
size: usizeSize of this struct in bytes. Must be set to sizeof(GhosttyTerminalSelectWordOptions).
ref_: GridRefGrid reference under which to derive the word selection.
boundary_codepoints: *const u32Optional word-boundary codepoints as uint32_t scalar values.
boundary_codepoints_len: usizeNumber of entries in boundary_codepoints.