pub type GhosttyKeyEncoder_ptr = *mut GhosttyKeyEncoder;Expand description
Opaque handle to a key encoder instance.
This handle represents a key encoder that converts key events into terminal escape sequences.
@ingroup key
pub type GhosttyKeyEncoder_ptr = *mut GhosttyKeyEncoder;Opaque handle to a key encoder instance.
This handle represents a key encoder that converts key events into terminal escape sequences.
@ingroup key