GhosttyKeyEvent_ptr

Type Alias GhosttyKeyEvent_ptr 

pub type GhosttyKeyEvent_ptr = *mut GhosttyKeyEvent;
Opaque handle to a key event.

This handle represents a keyboard input event containing information about the physical key pressed, modifiers, and generated text.

@ingroup key