pub type GhosttyMouseEvent_ptr = *mut GhosttyMouseEvent;Expand description
Opaque handle to a mouse event.
This handle represents a normalized mouse input event containing action, button, modifiers, and surface-space position.
@ingroup mouse
pub type GhosttyMouseEvent_ptr = *mut GhosttyMouseEvent;Opaque handle to a mouse event.
This handle represents a normalized mouse input event containing action, button, modifiers, and surface-space position.
@ingroup mouse