pub type GhosttyOscParser_ptr = *mut GhosttyOscParser;Expand description
Opaque handle to an OSC parser instance.
This handle represents an OSC (Operating System Command) parser that can be used to parse the contents of OSC sequences.
@ingroup osc
pub type GhosttyOscParser_ptr = *mut GhosttyOscParser;Opaque handle to an OSC parser instance.
This handle represents an OSC (Operating System Command) parser that can be used to parse the contents of OSC sequences.
@ingroup osc