GhosttyRowSemanticPrompt

Type Alias GhosttyRowSemanticPrompt 

pub type GhosttyRowSemanticPrompt = c_uint;
Row semantic prompt state.

Indicates whether any cells in a row are part of a shell prompt, as reported by OSC 133 sequences.

@ingroup screen