GhosttyTerminalSizeFn

Type Alias GhosttyTerminalSizeFn 

pub type GhosttyTerminalSizeFn = Option<unsafe extern "C" fn(terminal: GhosttyTerminal_ptr, userdata: *mut c_void, out_size: *mut GhosttySizeReportSize) -> bool>;
Callback function type for size queries (XTWINOPS).

Called in response to XTWINOPS size queries (CSI 14/16/18 t). Return true and fill *out_size with the current terminal geometry, or return false to silently ignore the query.

@param terminal The terminal handle @param userdata The userdata pointer set via GHOSTTY_TERMINAL_OPT_USERDATA @param[out] out_size Pointer to store the terminal size information @return true if size was filled, false to ignore the query

@ingroup terminal

Aliased Type

pub enum GhosttyTerminalSizeFn {
    None,
    Some(unsafe extern "C" fn(*mut GhosttyTerminal, *mut c_void, *mut GhosttySizeReportSize) -> bool),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut GhosttyTerminal, *mut c_void, *mut GhosttySizeReportSize) -> bool)

Some value of type T.