pub type KeyEncoder = *mut KeyEncoderImpl;Expand description
Opaque handle to a key encoder instance.
This handle represents a key encoder that converts key events into terminal escape sequences.
pub type KeyEncoder = *mut KeyEncoderImpl;Opaque handle to a key encoder instance.
This handle represents a key encoder that converts key events into terminal escape sequences.