pub type MouseEvent = *mut MouseEventImpl;Expand description
Opaque handle to a mouse event.
This handle represents a normalized mouse input event containing action, button, modifiers, and surface-space position.
pub type MouseEvent = *mut MouseEventImpl;Opaque handle to a mouse event.
This handle represents a normalized mouse input event containing action, button, modifiers, and surface-space position.