pub type OscCommand = *mut OscCommandImpl;Expand description
Opaque handle to a single OSC command.
This handle represents a parsed OSC (Operating System Command) command. The command can be queried for its type and associated data.
pub type OscCommand = *mut OscCommandImpl;Opaque handle to a single OSC command.
This handle represents a parsed OSC (Operating System Command) command. The command can be queried for its type and associated data.