pub type OscParser = *mut OscParserImpl;Expand description
Opaque handle to an OSC parser instance.
This handle represents an OSC (Operating System Command) parser that can be used to parse the contents of OSC sequences.
pub type OscParser = *mut OscParserImpl;Opaque handle to an OSC parser instance.
This handle represents an OSC (Operating System Command) parser that can be used to parse the contents of OSC sequences.