SelectionGesture

Type Alias SelectionGesture 

pub type SelectionGesture = *mut SelectionGestureImpl;
Opaque handle to state for interpreting terminal selection gestures.

The gesture owns only the state required to interpret pointer events. Calls that use a gesture are not concurrency-safe and must be serialized with terminal mutations.