SelectionGestureEvent

Type Alias SelectionGestureEvent 

pub type SelectionGestureEvent = *mut SelectionGestureEventImpl;
Opaque handle to reusable input data for selection gesture operations.

Event options are set with ghostty_selection_gesture_event_set(). Individual gesture operations document which options are required or optional.