pub type TerminalTitleChangedFn = Option<unsafe extern "C" fn(terminal: Terminal, userdata: *mut c_void)>;Expand description
Callback function type for title_changed.
Called when the terminal title changes via escape sequences (e.g. OSC 0 or OSC 2). The new title can be queried from the terminal after the callback returns.
Aliased Type
pub enum TerminalTitleChangedFn {
None,
Some(unsafe extern "C" fn(*mut TerminalImpl, *mut c_void)),
}