libghostty-vt-sys 0.1.0

Raw FFI bindings for libghostty-vt, the Ghostty terminal emulation library
docs.rs failed to build libghostty-vt-sys-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: libghostty-vt-sys-0.1.1

libghostty-vt-sys

Raw FFI bindings for libghostty-vt.

  • Fetches and builds libghostty-vt.so/.dylib from ghostty sources via Zig.
  • Exposes checked-in generated bindings in src/bindings.rs.
  • Set GHOSTTY_SOURCE_DIR to use a local ghostty checkout.