Populate a pre-allocated placement iterator with placement data from
the storage. Iterator data is only valid as long as the underlying
terminal is not mutated.
Populate a pre-allocated placement iterator with placement data from
the storage. Iterator data is only valid as long as the underlying
terminal is not mutated.