Populate a pre-allocated GhosttyRenderStateRowCells with cell data for
the current row (GhosttyRenderStateRowCells). Cell data is only
valid as long as the underlying render state is not updated.
It is unsafe to use cell data after updating the render state.