Skip to main contentModule SelectionAdjust
Source - BEGINNING_OF_LINE
- Move to the left edge of the current line.
- DOWN
- Move down to the next non-blank row at the current column, or to the
end of the line if none exists.
- END
- Move to the right edge of the last non-blank row on the screen.
- END_OF_LINE
- Move to the right edge of the current line.
- HOME
- Move to the top-left cell of the screen.
- LEFT
- Move left to the previous non-empty cell, wrapping upward.
- MAX_VALUE
- Move to the right edge of the current line.
- PAGE_DOWN
- Move down by one terminal page height, or to end if that would move
past the bottom.
- PAGE_UP
- Move up by one terminal page height, or to home if that would move
past the top.
- RIGHT
- Move right to the next non-empty cell, wrapping downward.
- UP
- Move up one row at the current column, or to the beginning of the
line if already at the top.
- Type
- Operation used to adjust a selection endpoint.