Constants
- ACTIVE_
SCREEN - The currently active screen.
- COLOR_
BACKGROUND - The effective background color (override or default).
- COLOR_
BACKGROUND_ DEFAULT - The default background color (ignoring any OSC override).
- COLOR_
CURSOR - The effective cursor color (override or default).
- COLOR_
CURSOR_ DEFAULT - The default cursor color (ignoring any OSC override).
- COLOR_
FOREGROUND - The effective foreground color (override or default).
- COLOR_
FOREGROUND_ DEFAULT - The default foreground color (ignoring any OSC override).
- COLOR_
PALETTE - The current 256-color palette.
- COLOR_
PALETTE_ DEFAULT - The default 256-color palette (ignoring any OSC overrides).
- COLS
- Terminal width in cells.
- CURSOR_
PENDING_ WRAP - Whether the cursor has a pending wrap (next print will soft-wrap).
- CURSOR_
STYLE - The current SGR style of the cursor.
- CURSOR_
VISIBLE - Whether the cursor is visible (DEC mode 25).
- CURSOR_
X - Cursor column position (0-indexed).
- CURSOR_
Y - Cursor row position within the active area (0-indexed).
- HEIGHT_
PX - The total height of the terminal in pixels.
- INVALID
- Invalid data type. Never results in any data extraction.
- KITTY_
GRAPHICS - The Kitty graphics image storage for the active screen.
- KITTY_
IMAGE_ MEDIUM_ FILE - Whether the file medium is enabled for Kitty image loading on the active screen.
- KITTY_
IMAGE_ MEDIUM_ SHARED_ MEM - Whether the shared memory medium is enabled for Kitty image loading on the active screen.
- KITTY_
IMAGE_ MEDIUM_ TEMP_ FILE - Whether the temporary file medium is enabled for Kitty image loading on the active screen.
- KITTY_
IMAGE_ STORAGE_ LIMIT - The Kitty image storage limit in bytes for the active screen.
- KITTY_
KEYBOARD_ FLAGS - Current Kitty keyboard protocol flags.
- MAX_
VALUE - Whether the viewport is currently pinned to the active area.
- MOUSE_
TRACKING - Whether any mouse tracking mode is active.
- PWD
- The terminal’s current working directory as set by escape sequences (e.g. OSC 7).
- ROWS
- Terminal height in cells.
- SCROLLBACK_
ROWS - The number of scrollback rows (total rows minus viewport rows).
- SCROLLBAR
- Scrollbar state for the terminal viewport.
- SELECTION
- The active screen’s current selection.
- TITLE
- The terminal title as set by escape sequences (e.g. OSC 0/2).
- TOTAL_
ROWS - The total number of rows in the active screen including scrollback.
- VIEWPORT_
ACTIVE - Whether the viewport is currently pinned to the active area.
- WIDTH_
PX - The total width of the terminal in pixels.
Type Aliases
- Type
- Terminal data types.