pub unsafe extern "C" fn ghostty_cell_get(
cell: Cell,
data: Type,
out: *mut c_void,
) -> TypeExpand description
Get data from a cell.
Extracts typed data from the given cell based on the specified
data type. The output pointer must be of the appropriate type for the
requested data kind. Valid data types and output types are documented
in the GhosttyCellData enum.
data type is invalid