ghostty_mouse_encoder_encode

Function ghostty_mouse_encoder_encode 

pub unsafe extern "C" fn ghostty_mouse_encoder_encode(
    encoder: MouseEncoder,
    event: MouseEvent,
    out_buf: *mut c_char,
    out_buf_size: usize,
    out_len: *mut usize,
) -> Type
Encode a mouse event into a terminal escape sequence.

Not all mouse events produce output. In such cases this returns GHOSTTY_SUCCESS with out_len set to 0.

If the output buffer is too small, this returns GHOSTTY_OUT_OF_SPACE and out_len contains the required size.

    or another error code