pub unsafe extern "C" fn ghostty_mouse_event_get_button(
event: GhosttyMouseEvent_ptr,
out_button: *mut GhosttyMouseButton,
) -> boolExpand description
Get the event button.
@param event The event handle, must not be NULL @param out_button Output pointer for the button value (may be NULL) @return true if a button is set, false if no button is set
@ingroup mouse