ghostty_osc_command_data

Function ghostty_osc_command_data 

pub unsafe extern "C" fn ghostty_osc_command_data(
    command: OscCommand,
    data: Type,
    out: *mut c_void,
) -> bool
Extract data from an OSC command.

Extracts typed data from the given OSC command based on the specified data type. The output pointer must be of the appropriate type for the requested data kind. Valid command types, output types, and memory safety information are documented in the GhosttyOscCommandData enum.