pub unsafe extern "C" fn ghostty_render_state_free(
state: GhosttyRenderState_ptr,
)Expand description
Free a render state instance.
Releases all resources associated with the render state. After this call, the render state handle becomes invalid.
@param state The render state handle to free (may be NULL)
@ingroup render