pub unsafe extern "C" fn ghostty_render_state_get(
state: GhosttyRenderState_ptr,
data: GhosttyRenderStateData,
out: *mut c_void,
) -> GhosttyResultExpand description
Get a value from a render state.
The out pointer must point to a value of the type corresponding to the
requested data kind (see GhosttyRenderStateData).
@param state The render state handle (NULL returns GHOSTTY_INVALID_VALUE)
@param data The data kind to query
@param[out] out Pointer to receive the queried value
@return GHOSTTY_SUCCESS on success, GHOSTTY_INVALID_VALUE if state is
NULL or data is not a recognized enum value
@ingroup render