pub unsafe extern "C" fn ghostty_render_state_row_iterator_next(
iterator: GhosttyRenderStateRowIterator_ptr,
) -> boolExpand description
Move a render-state row iterator to the next row.
Returns true if the iterator moved successfully and row data is available to read at the new position.
@param iterator The iterator handle to advance (may be NULL)
@return true if advanced to the next row, false if iterator is
NULL or if the iterator has reached the end
@ingroup render