ghostty_render_state_row_set

Function ghostty_render_state_row_set 

pub unsafe extern "C" fn ghostty_render_state_row_set(
    iterator: RenderStateRowIterator,
    option: Type,
    value: *const c_void,
) -> Type
Set an option on the current row in a render-state row iterator.

The value pointer must point to a value of the type corresponding to the requested option kind (see GhosttyRenderStateRowOption). Call ghostty_render_state_row_iterator_next() at least once before calling this function.

       GHOSTTY_INVALID_VALUE)
    `iterator` is NULL or the iterator is not positioned on a row