pub unsafe extern "C" fn ghostty_render_state_update(
state: GhosttyRenderState_ptr,
terminal: GhosttyTerminal_ptr,
) -> GhosttyResultExpand description
Update a render state instance from a terminal.
This consumes terminal/screen dirty state in the same way as the internal render state update path.
@param state The render state handle (NULL returns GHOSTTY_INVALID_VALUE)
@param terminal The terminal handle to read from (NULL returns GHOSTTY_INVALID_VALUE)
@return GHOSTTY_SUCCESS on success, GHOSTTY_INVALID_VALUE if state or
terminal is NULL, GHOSTTY_OUT_OF_MEMORY if updating the state requires
allocation and that allocation fails
@ingroup render