ghostty_render_state_update

Function ghostty_render_state_update 

pub unsafe extern "C" fn ghostty_render_state_update(
    state: RenderState,
    terminal: Terminal,
) -> Type
Update a render state instance from a terminal.

This consumes terminal/screen dirty state in the same way as the internal render state update path.

terminal is NULL, GHOSTTY_OUT_OF_MEMORY if updating the state requires allocation and that allocation fails