pub unsafe extern "C" fn ghostty_selection_gesture_reset(
gesture: SelectionGesture,
terminal: Terminal,
)Expand description
Reset any active selection gesture state.
This cancels the active click sequence and releases any tracked terminal references owned by the gesture without freeing the gesture object. Passing NULL is allowed and is a no-op.