ghostty_sgr_attribute_value

Function ghostty_sgr_attribute_value 

pub unsafe extern "C" fn ghostty_sgr_attribute_value(
    attr: *mut SgrAttribute,
) -> *mut SgrAttributeValue
Get the value from an SGR attribute.

This function returns a pointer to the value union from an SGR attribute. Use the tag to determine which field of the union is valid. Primarily useful in WebAssembly environments where accessing struct fields directly is difficult.