pub unsafe extern "C" fn ghostty_sgr_unknown_partial(
unknown: SgrUnknown,
ptr: *mut *const u16,
) -> usizeExpand description
Get the partial parameter list from an unknown SGR attribute.
This function retrieves the partial parameter list where parsing stopped when an unknown attribute was encountered. Primarily useful in WebAssembly environments where accessing struct fields directly is difficult.