pub unsafe extern "C" fn ghostty_size_report_encode(
style: Type,
size: SizeReportSize,
buf: *mut c_char,
buf_len: usize,
out_written: *mut usize,
) -> TypeExpand description
Encode a terminal size report into an escape sequence.
Encodes a size report in the format specified by @p style into the provided buffer.
If the buffer is too small, the function returns GHOSTTY_OUT_OF_SPACE and writes the required buffer size to @p out_written. The caller can then retry with a sufficiently sized buffer.
GHOSTTY_OUT_OF_SPACE, the required buffer size.
is too small