pub type GhosttyKey = c_uint;Expand description
Physical key codes.
The set of key codes that Ghostty is aware of. These represent physical keys on the keyboard and are layout-independent. For example, the “a” key on a US keyboard is the same as the “ф” key on a Russian keyboard, but both will report the same key_a value.
Layout-dependent strings are provided separately as UTF-8 text and are produced by the platform. These values are based on the W3C UI Events KeyboardEvent code standard. See: https://www.w3.org/TR/uievents-code
@ingroup key