pub type GhosttyTerminalTitleChangedFn = Option<unsafe extern "C" fn(terminal: GhosttyTerminal_ptr, userdata: *mut c_void)>;Expand description
Callback function type for title_changed.
Called when the terminal title changes via escape sequences (e.g. OSC 0 or OSC 2). The new title can be queried from the terminal after the callback returns.
@param terminal The terminal handle @param userdata The userdata pointer set via GHOSTTY_TERMINAL_OPT_USERDATA
@ingroup terminal
Aliased Type
pub enum GhosttyTerminalTitleChangedFn {
None,
Some(unsafe extern "C" fn(*mut GhosttyTerminal, *mut c_void)),
}