pub type KeyEvent = *mut KeyEventImpl;Expand description
Opaque handle to a key event.
This handle represents a keyboard input event containing information about the physical key pressed, modifiers, and generated text.
pub type KeyEvent = *mut KeyEventImpl;Opaque handle to a key event.
This handle represents a keyboard input event containing information about the physical key pressed, modifiers, and generated text.