pub type SysLogFn = Option<unsafe extern "C" fn(userdata: *mut c_void, level: Type, scope: *const u8, scope_len: usize, message: *const u8, message_len: usize)>;Expand description
Callback type for logging.
When installed, internal library log messages are delivered through this callback instead of being discarded. The embedder is responsible for formatting and routing log output.
When the log is unscoped (default scope), @p scope_len is 0.
All pointer arguments are only valid for the duration of the callback. The callback must be safe to call from any thread.
Aliased Type
pub enum SysLogFn {
None,
Some(unsafe extern "C" fn(*mut c_void, u32, *const u8, usize, *const u8, usize)),
}